@@ -1,6 +1,6 @@
 /* packet-tcap.h
  *
- * $Id: packet-tcap-template.h 20257 2007-01-01 22:03:01Z etxrab $
+ * $Id: packet-tcap-template.h 22415 2007-07-27 19:24:40Z morriss $
  *
  * Copyright 2004, Tim Endean <endeant@hotmail.com>
  *
@@ -41,13 +41,14 @@
 #define ANSI_TC_INVOKE_N	0xed
 #define ANSI_TC_RRN		0xee
 
+
 #define	TCAP_SEQ_TAG		0x30
 #define	TCAP_SET_TAG		0x31
 
 #define TCAP_INVOKE_ID_TAG	0x02
 #define TCAP_LINKED_ID_TAG	0x80
 
-#define	TCAP_EOC_LEN		2		
+#define	TCAP_EOC_LEN		2
 
 #define	TCAP_CONSTRUCTOR(TCtag)	(TCtag & 0x20)
 
@@ -55,6 +56,8 @@
 #define TC_CONT 2
 #define TC_END 3
 #define TC_ABORT 4
+#define TC_ANSI_ABORT 5
+#define TC_ANSI_ALL 6
 
 struct tcap_private_t {
   gboolean acv; /* Is the Application Context Version present */
@@ -67,8 +70,11 @@ struct tcap_private_t {
 extern gint tcap_standard;
 
 extern const value_string tcap_component_type_str[];
+void proto_reg_handoff_tcap(void);
+void proto_register_tcap(void);
 
 extern dissector_handle_t get_itu_tcap_subdissector(guint32 ssn);
+dissector_handle_t get_ansi_tcap_subdissector(guint32 ssn);
 
 extern void add_ansi_tcap_subdissector(guint32 ssn, dissector_handle_t dissector);
 extern void add_itu_tcap_subdissector(guint32 ssn, dissector_handle_t dissector);
@@ -76,4 +82,8 @@ extern void add_itu_tcap_subdissector(guint32 ssn, dissector_handle_t dissector)
 extern void delete_ansi_tcap_subdissector(guint32 ssn, dissector_handle_t dissector);
 extern void delete_itu_tcap_subdissector(guint32 ssn, dissector_handle_t dissector);
 
+extern void call_tcap_dissector(dissector_handle_t, tvbuff_t*, packet_info*, proto_tree*);
+
+#include "packet-tcap-exp.h"
+
 #endif  /* PACKET_tcap_H */
