@@ -5,7 +5,7 @@
  * Full Tacacs+ parsing with decryption by
  *   Emanuele Caratti <wiz@iol.it>
  *
- * $Id: packet-tacacs.c 27065 2008-12-20 00:09:02Z wmeier $
+ * $Id: packet-tacacs.c 28356 2009-05-13 19:46:11Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -249,55 +249,55 @@ proto_register_tacacs(void)
 	  { &hf_tacacs_version,
 	    { "Version",           "tacacs.version",
 	      FT_UINT8, BASE_HEX, VALS(tacacs_version_vals), 0x0,
-	      "Version", HFILL }},
+	      NULL, HFILL }},
 	  { &hf_tacacs_type,
 	    { "Type",              "tacacs.type",
 	      FT_UINT8, BASE_DEC, VALS(tacacs_type_vals), 0x0,
-	      "Type", HFILL }},
+	      NULL, HFILL }},
 	  { &hf_tacacs_nonce,
 	    { "Nonce",             "tacacs.nonce",
 	      FT_UINT16, BASE_HEX, NULL, 0x0,
-	      "Nonce", HFILL }},
+	      NULL, HFILL }},
 	  { &hf_tacacs_userlen,
 	    { "Username length",   "tacacs.userlen",
 	      FT_UINT8, BASE_DEC, NULL, 0x0,
-	      "Username length", HFILL }},
+	      NULL, HFILL }},
 	  { &hf_tacacs_passlen,
 	    { "Password length",   "tacacs.passlen",
 	      FT_UINT8, BASE_DEC, NULL, 0x0,
-	      "Password length", HFILL }},
+	      NULL, HFILL }},
 	  { &hf_tacacs_response,
 	    { "Response",          "tacacs.response",
 	      FT_UINT8, BASE_DEC, VALS(tacacs_resp_vals), 0x0,
-	      "Response", HFILL }},
+	      NULL, HFILL }},
 	  { &hf_tacacs_reason,
 	    { "Reason",            "tacacs.reason",
 	      FT_UINT8, BASE_DEC, VALS(tacacs_reason_vals), 0x0,
-	      "Reason", HFILL }},
+	      NULL, HFILL }},
 	  { &hf_tacacs_result1,
 	    { "Result 1",          "tacacs.result1",
 	      FT_UINT32, BASE_HEX, NULL, 0x0,
-	      "Result 1", HFILL }},
+	      NULL, HFILL }},
 	  { &hf_tacacs_destaddr,
 	    { "Destination address", "tacacs.destaddr",
 	      FT_IPv4, BASE_NONE, NULL, 0x0,
-	      "Destination address", HFILL }},
+	      NULL, HFILL }},
 	  { &hf_tacacs_destport,
 	    { "Destination port",  "tacacs.destport",
 	      FT_UINT16, BASE_DEC, NULL, 0x0,
-	      "Destination port", HFILL }},
+	      NULL, HFILL }},
 	  { &hf_tacacs_line,
 	    { "Line",              "tacacs.line",
 	      FT_UINT16, BASE_DEC, NULL, 0x0,
-	      "Line", HFILL }},
+	      NULL, HFILL }},
 	  { &hf_tacacs_result2,
 	    { "Result 2",          "tacacs.result2",
 	      FT_UINT32, BASE_HEX, NULL, 0x0,
-	      "Result 2", HFILL }},
+	      NULL, HFILL }},
 	  { &hf_tacacs_result3,
 	    { "Result 3",          "tacacs.result3",
 	      FT_UINT16, BASE_HEX, NULL, 0x0,
-	      "Result 3", HFILL }},
+	      NULL, HFILL }},
 	};
 
 	static gint *ett[] = {
@@ -360,17 +360,12 @@ tacplus_decrypted_tvb_setup( tvbuff_t *tvb, tvbuff_t **dst_tvb, packet_info *pin
 	md5_xor( buff, key, len, session_id,version, tvb_get_guint8(tvb,2) );
 
 	/* Allocate a new tvbuff, referring to the decrypted data. */
-	*dst_tvb = tvb_new_real_data( buff, len, len );
+	*dst_tvb = tvb_new_child_real_data(tvb,  buff, len, len );
 
 	/* Arrange that the allocated packet data copy be freed when the
 	   tvbuff is freed. */
 	tvb_set_free_cb( *dst_tvb, g_free );
 
-	/* Add the tvbuff to the list of tvbuffs to which the tvbuff we
-	   were handed refers, so it'll get cleaned up when that tvbuff
-	   is cleaned up. */
-	tvb_set_child_real_data_tvbuff( tvb, *dst_tvb );
-
 	/* Add the decrypted data to the data source list. */
 	add_new_data_source(pinfo, *dst_tvb, "TACACS+ Decrypted");
 
@@ -1061,15 +1056,15 @@ proto_register_tacplus(void)
 	  { &hf_tacplus_type,
 	    { "Type",               "tacplus.type",
 	      FT_UINT8, BASE_DEC, VALS(tacplus_type_vals), 0x0,
-	      "Type", HFILL }},
+	      NULL, HFILL }},
 	  { &hf_tacplus_seqno,
 	    { "Sequence number",    "tacplus.seqno",
 	      FT_UINT8, BASE_DEC, NULL, 0x0,
-	      "Sequence number", HFILL }},
+	      NULL, HFILL }},
 	  { &hf_tacplus_flags,
 	    { "Flags",              "tacplus.flags",
 	      FT_UINT8, BASE_HEX, NULL, 0x0,
-	      "Flags", HFILL }},
+	      NULL, HFILL }},
 	  { &hf_tacplus_flags_payload_type,
 	    { "Unencrypted",       "tacplus.flags.unencrypted",
 	      FT_BOOLEAN, 8, TFS(&flags_set_truth), FLAGS_UNENCRYPTED,
@@ -1081,15 +1076,15 @@ proto_register_tacplus(void)
 	  { &hf_tacplus_acct_flags,
 	    { "Flags",    "tacplus.acct.flags",
 	      FT_UINT8, BASE_HEX, NULL, 0x0,
-	      "Flags", HFILL }},
+	      NULL, HFILL }},
 	  { &hf_tacplus_session_id,
 	    { "Session ID",         "tacplus.session_id",
 	      FT_UINT32, BASE_DEC, NULL, 0x0,
-	      "Session ID", HFILL }},
+	      NULL, HFILL }},
 	  { &hf_tacplus_packet_len,
 	    { "Packet length",      "tacplus.packet_len",
 	      FT_UINT32, BASE_DEC, NULL, 0x0,
-	      "Packet length", HFILL }}
+	      NULL, HFILL }}
 	};
 	static gint *ett[] = {
 		&ett_tacplus,
@@ -1127,7 +1122,8 @@ proto_reg_handoff_tacplus(void)
 static void
 md5_xor( guint8 *data, const char *key, int data_len, guint8 *session_id, guint8 version, guint8 seq_no )
 {
-	int i,j,md5_len;
+	int i,j;
+	size_t md5_len;
 	md5_byte_t *md5_buff;
 	md5_byte_t hash[MD5_LEN];       				/* the md5 hash */
 	md5_byte_t *mdp;
