@@ -1,7 +1,7 @@
 /* packet-tns.c
  * Routines for Oracle TNS packet dissection
  *
- * $Id: packet-tns.c 19751 2006-10-31 09:29:07Z sahlberg $
+ * $Id: packet-tns.c 26091 2008-08-26 01:28:50Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -33,7 +33,6 @@
 #include <string.h>
 #include <glib.h>
 #include <epan/packet.h>
-#include <epan/emem.h>
 #include "packet-tcp.h"
 #include "packet-tns.h"
 
@@ -244,6 +243,7 @@ static void dissect_tns_data(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	proto_tree *tree, proto_tree *tns_tree)
 {
 	proto_tree *data_tree = NULL, *ti;
+	proto_item *hidden_item;
 	int is_sns = 0;
 
 	if ( tvb_bytes_exist(tvb, offset+2, 4) )
@@ -271,8 +271,9 @@ static void dissect_tns_data(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		}
 		data_tree = proto_item_add_subtree(ti, ett_tns_data);
 
-		proto_tree_add_boolean_hidden(tns_tree, hf_tns_data, tvb, 0, 0,
-				TRUE);
+		hidden_item = proto_tree_add_boolean(tns_tree, hf_tns_data, tvb, 0, 0,
+					TRUE);
+		PROTO_ITEM_SET_HIDDEN(hidden_item);
 	}
 
 	if ( tree )
@@ -298,11 +299,11 @@ static void dissect_tns_data(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	{
 		if ( is_sns )
 		{
-			col_append_fstr(pinfo->cinfo, COL_INFO, ", SNS");
+			col_append_str(pinfo->cinfo, COL_INFO, ", SNS");
 		}
 		else
 		{
-			col_append_fstr(pinfo->cinfo, COL_INFO, ", Data");
+			col_append_str(pinfo->cinfo, COL_INFO, ", Data");
 		}
 	}
 
@@ -319,6 +320,7 @@ static void dissect_tns_connect(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	proto_tree *tree, proto_tree *tns_tree)
 {
 	proto_tree *connect_tree = NULL, *ti;
+	proto_item *hidden_item;
 	int cd_offset;
 	int cd_len;
 	int tns_offset = offset-8;
@@ -329,8 +331,9 @@ static void dissect_tns_connect(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		    "Connect");
 		connect_tree = proto_item_add_subtree(ti, ett_tns_connect);
 
-		proto_tree_add_boolean_hidden(tns_tree, hf_tns_connect, tvb,
-		    0, 0, TRUE);
+		hidden_item = proto_tree_add_boolean(tns_tree, hf_tns_connect, tvb,
+				    0, 0, TRUE);
+		PROTO_ITEM_SET_HIDDEN(hidden_item);
 	}
 
 	if ( check_col(pinfo->cinfo, COL_INFO) )
@@ -512,6 +515,7 @@ static void dissect_tns_accept(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	proto_tree *tree, proto_tree *tns_tree)
 {
 	proto_tree *accept_tree = NULL, *ti;
+	proto_item *hidden_item;
 	int accept_offset;
 	int accept_len;
 	int tns_offset = offset-8;
@@ -522,8 +526,9 @@ static void dissect_tns_accept(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		    "Accept");
 		accept_tree = proto_item_add_subtree(ti, ett_tns_accept);
 
-		proto_tree_add_boolean_hidden(tns_tree, hf_tns_accept, tvb,
-		    0, 0, TRUE);
+		hidden_item = proto_tree_add_boolean(tns_tree, hf_tns_accept, tvb,
+				    0, 0, TRUE);
+		PROTO_ITEM_SET_HIDDEN(hidden_item);
 	}
 
 	if ( check_col(pinfo->cinfo, COL_INFO) )
@@ -630,6 +635,7 @@ static void dissect_tns_refuse(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	proto_tree *tree, proto_tree *tns_tree)
 {
 	proto_tree *refuse_tree = NULL, *ti;
+	proto_item *hidden_item;
 
 	if ( tree )
 	{
@@ -637,8 +643,9 @@ static void dissect_tns_refuse(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		    "Refuse");
 		refuse_tree = proto_item_add_subtree(ti, ett_tns_refuse);
 
-		proto_tree_add_boolean_hidden(tns_tree, hf_tns_refuse, tvb,
-		    0, 0, TRUE);
+		hidden_item = proto_tree_add_boolean(tns_tree, hf_tns_refuse, tvb,
+				    0, 0, TRUE);
+		PROTO_ITEM_SET_HIDDEN(hidden_item);
 	}
 
 	if ( check_col(pinfo->cinfo, COL_INFO) )
@@ -680,6 +687,7 @@ static void dissect_tns_abort(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	proto_tree *tree, proto_tree *tns_tree)
 {
 	proto_tree *abort_tree = NULL, *ti;
+	proto_item *hidden_item;
 
 	if ( tree )
 	{
@@ -687,8 +695,9 @@ static void dissect_tns_abort(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		    "Abort");
 		abort_tree = proto_item_add_subtree(ti, ett_tns_abort);
 
-		proto_tree_add_boolean_hidden(tns_tree, hf_tns_abort, tvb,
-		    0, 0, TRUE);
+		hidden_item = proto_tree_add_boolean(tns_tree, hf_tns_abort, tvb,
+				    0, 0, TRUE);
+		PROTO_ITEM_SET_HIDDEN(hidden_item);
 	}
 
 	if ( check_col(pinfo->cinfo, COL_INFO) )
@@ -723,6 +732,7 @@ static void dissect_tns_marker(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	proto_tree *tree, proto_tree *tns_tree, int is_attention)
 {
 	proto_tree *marker_tree = NULL, *ti;
+	proto_item *hidden_item;
 
 	if ( tree )
 	{
@@ -738,8 +748,9 @@ static void dissect_tns_marker(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		}
 
 		marker_tree = proto_item_add_subtree(ti, ett_tns_marker);
-		proto_tree_add_boolean_hidden(tns_tree, hf_tns_marker, tvb,
-		    0, 0, TRUE);
+		hidden_item = proto_tree_add_boolean(tns_tree, hf_tns_marker, tvb,
+				    0, 0, TRUE);
+		PROTO_ITEM_SET_HIDDEN(hidden_item);
 	}
 
 	if ( check_col(pinfo->cinfo, COL_INFO) )
@@ -782,6 +793,7 @@ static void dissect_tns_redirect(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	proto_tree *tree, proto_tree *tns_tree)
 {
 	proto_tree *redirect_tree = NULL, *ti;
+	proto_item *hidden_item;
 
 	if ( tree )
 	{
@@ -789,8 +801,9 @@ static void dissect_tns_redirect(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		    "Redirect");
 		redirect_tree = proto_item_add_subtree(ti, ett_tns_redirect);
 
-		proto_tree_add_boolean_hidden(tns_tree, hf_tns_redirect, tvb,
-		    0, 0, TRUE);
+		hidden_item = proto_tree_add_boolean(tns_tree, hf_tns_redirect, tvb,
+				    0, 0, TRUE);
+		PROTO_ITEM_SET_HIDDEN(hidden_item);
 	}
 
 	if ( check_col(pinfo->cinfo, COL_INFO) )
@@ -817,6 +830,7 @@ static void dissect_tns_control(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	proto_tree *tree, proto_tree *tns_tree)
 {
 	proto_tree *control_tree = NULL, *ti;
+	proto_item *hidden_item;
 
 	if ( tree )
 	{
@@ -824,8 +838,9 @@ static void dissect_tns_control(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		    "Control");
 		control_tree = proto_item_add_subtree(ti, ett_tns_control);
 
-		proto_tree_add_boolean_hidden(tns_tree, hf_tns_control, tvb,
-		    0, 0, TRUE);
+		hidden_item = proto_tree_add_boolean(tns_tree, hf_tns_control, tvb,
+				    0, 0, TRUE);
+		PROTO_ITEM_SET_HIDDEN(hidden_item);
 	}
 
 	if ( check_col(pinfo->cinfo, COL_INFO) )
@@ -885,6 +900,7 @@ static void
 dissect_tns_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 	proto_tree      *tns_tree = NULL, *ti;
+	proto_item *hidden_item;
 	int offset = 0;
 	guint16 length;
 	guint16 type;
@@ -894,7 +910,7 @@ dissect_tns_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	if (check_col(pinfo->cinfo, COL_INFO))
 	{
-		col_add_str(pinfo->cinfo, COL_INFO,
+		col_set_str(pinfo->cinfo, COL_INFO,
 			(pinfo->match_port == pinfo->destport) ? "Request" : "Response");
 	}
 
@@ -905,14 +921,15 @@ dissect_tns_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 		if (pinfo->match_port == pinfo->destport)
 		{
-			proto_tree_add_boolean_hidden(tns_tree, hf_tns_request,
-			   tvb, offset, 0, TRUE);
+			hidden_item = proto_tree_add_boolean(tns_tree, hf_tns_request,
+					   tvb, offset, 0, TRUE);
 		}
 		else
 		{
-			proto_tree_add_boolean_hidden(tns_tree, hf_tns_response,
-			    tvb, offset, 0, TRUE);
+			hidden_item = proto_tree_add_boolean(tns_tree, hf_tns_response,
+					    tvb, offset, 0, TRUE);
 		}
+		PROTO_ITEM_SET_HIDDEN(hidden_item);
 	}
 
 	length = tvb_get_ntohs(tvb, offset);
