@@ -5,7 +5,7 @@
  *
  * Author: Mike Harvey <michael.harvey@intel.com>
  *
- * $Id: msg_dlmap.c 23787 2007-12-06 18:53:58Z gerald $
+ * $Id: msg_dlmap.c 26103 2008-08-29 01:40:32Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -36,7 +36,6 @@
 
 #include <glib.h>
 #include <epan/packet.h>
-#include <epan/prefs.h>
 #include "crc.h"
 #include "wimax_bits.h"
 
@@ -705,24 +704,24 @@ gint RCID_IE(proto_tree *diuc_tree, const guint8 *bufptr, gint offset, gint leng
     tree = proto_item_add_subtree(ti, ett_286j);
 
     if (RCID_Type == 0) {
-	XBIT(cid, 16, "CID");
+        XBIT(cid, 16, "CID");
     } else {
         proto_tree_add_text(tree, tvb, BITHI(bit,1), "Prefix: %d", Prefix);
         bit++;
 
         if (Prefix == 1) {
             /* RCID 11 */
-	    XBIT(cid, 11, "CID11");
+            XBIT(cid, 11, "CID11");
         } else {
             if (RCID_Type == 1) {
                 /* RCID 11 */
-		XBIT(cid, 11, "CID11");
+                XBIT(cid, 11, "CID11");
             } else if (RCID_Type == 2) {
                 /* RCID 7 */
-		XBIT(cid, 7, "CID7");
+                XBIT(cid, 7, "CID7");
             } else if (RCID_Type == 3) {
                 /* RCID 3 */
-		XBIT(cid, 3, "CID3");
+                XBIT(cid, 3, "CID3");
             }
         }
     }
@@ -761,17 +760,17 @@ gint Dedicated_DL_Control_IE(proto_tree *diuc_tree, const guint8 *bufptr, gint o
     if ((nibble & 1) == 1) {
         nibble = NIB_NIBBLE(nib, bufptr);
         proto_tree_add_text(tree, tvb, NIBHI(nib,1), "Num SDMA Layers: %d", (nibble >> 2) & 0x3);
-	/* Bit padding */
-	if ((nib*4)+2 < (offset+length)*4) {
-	    len = ((offset + length - nib) * 4) - 2;
-	    proto_tree_add_text(tree, tvb, BITHI(nib*4, len), "Reserved bits");
-	}
+        /* Bit padding */
+        if ((nib*4)+2 < (offset+length)*4) {
+            len = ((offset + length - nib) * 4) - 2;
+            proto_tree_add_text(tree, tvb, BITHI(nib*4, len), "Reserved bits");
+        }
     } else {
-	    /* Nibble padding */
-	    if (nib < offset+length) {
-		len = (offset + length) - nib;
-		proto_tree_add_text(tree, tvb, NIBHI(nib,len), "Reserved bits");
-	    }
+        /* Nibble padding */
+        if (nib < offset+length) {
+            len = (offset + length) - nib;
+            proto_tree_add_text(tree, tvb, NIBHI(nib,len), "Reserved bits");
+        }
     }
     return (length + 1);
 }
@@ -800,25 +799,25 @@ gint Dedicated_MIMO_DL_Control_IE(proto_tree *diuc_tree, const guint8 *bufptr, g
 
     /* MIMO Control Info */
     if (mci == 1) {
-	XBIT(matrix, 2, "Matrix");
+        XBIT(matrix, 2, "Matrix");
         if (STC_Zone_Dedicated_Pilots == 1) {
-	    XBIT(data, 2, "Num_Beamformed_Streams");
+            XBIT(data, 2, "Num_Beamformed_Streams");
         }
     }
 
     /* CQICH Control Info */
     if (cqi == 1) {
         CQICH_num = 0;
-	XBIT(data, 3, "Period");
-	XBIT(data, 3, "Frame Offset");
-	XBIT(data, 4, "Duration");
+        XBIT(data, 3, "Period");
+        XBIT(data, 3, "Frame Offset");
+        XBIT(data, 4, "Duration");
         for (j = 0; j < N_layer; j++) {
-	    XBIT(data, 6, "Allocation Index");
+            XBIT(data, 6, "Allocation Index");
         }
-	XBIT(CQICH_num, 2, "CQICH_Num");
+        XBIT(CQICH_num, 2, "CQICH_Num");
         for (j = 0; j < CQICH_num; j++) {
-	    XBIT(data, 3, "Feedback type");
-	    XBIT(data, 6, "Allocation index");
+            XBIT(data, 3, "Feedback type");
+            XBIT(data, 6, "Allocation index");
         }
     }
 
@@ -830,21 +829,21 @@ gint Dedicated_MIMO_DL_Control_IE(proto_tree *diuc_tree, const guint8 *bufptr, g
             mimo_mode = STC_Zone_Matrix;
         }
         if (mimo_mode == 0 || mimo_mode == 1) {
-	    XBIT(data, 3, "Antenna Grouping Index");
+            XBIT(data, 3, "Antenna Grouping Index");
         } else if (mimo_mode == 2) {
-	    XBIT(data, 2, "Num_stream");
-	    XBIT(data, 3, "Antenna Selection Index");
+            XBIT(data, 2, "Num_stream");
+            XBIT(data, 3, "Antenna Selection Index");
         } else if (mimo_mode == 3) {
-	    XBIT(data, 2, "Num_stream");
-	    XBIT(data, 6, "Codebook Precoding Index");
+            XBIT(data, 2, "Num_stream");
+            XBIT(data, 6, "Codebook Precoding Index");
         }
     }
 
     /* padding to nibble */
     pad = BIT_PADDING(bit,4);
     if(pad){
-	proto_tree_add_text(tree, tvb, BITHI(bit,pad), "Padding: %d bits", pad);
-	bit += pad;
+        proto_tree_add_text(tree, tvb, BITHI(bit,pad), "Padding: %d bits", pad);
+        bit += pad;
     }
 
     return (bit - offset);
@@ -864,35 +863,36 @@ gint DL_HARQ_Chase_sub_burst_IE(proto_tree *diuc_tree, const guint8 *bufptr, gin
     bit = NIB_TO_BIT(offset);
 
     /* 8.4.5.3.21 table 286m */
-    ti = proto_tree_add_text(diuc_tree, tvb, BITHI(bit, 4), "DL_HARQ_Chase_sub_burst_IE");
+    ti = proto_tree_add_text(diuc_tree, tvb, BITHI(bit, length), "DL_HARQ_Chase_sub_burst_IE");
     tree = proto_item_add_subtree(ti, ett_286m);
 
     XBIT(nsub, 4, "N sub burst[ISI]");
     XBIT(data, 4, "N ACK channel");
 
+    nsub += 1;
     for (j = 0; j < nsub; j++) {
         bit += RCID_IE(tree, bufptr, bit, length, tvb, RCID_Type);
-	XBIT(dur, 10, "Duration");
-	XBIT(sbi,  1, "Sub-Burst DIUC Indicator");
-	XBIT(res,  1, "Reserved");
+        XBIT(dur, 10, "Duration");
+        XBIT(sbi,  1, "Sub-Burst DIUC Indicator");
+        XBIT(res,  1, "Reserved");
 
         if (sbi == 1) {
-	    XBIT(diuc, 4, "DIUC");
-	    XBIT(rci, 2, "Repetition Coding Indication");
-	    XBIT(res, 2, "Reserved");
+            XBIT(diuc, 4, "DIUC");
+            XBIT(rci, 2, "Repetition Coding Indication");
+            XBIT(res, 2, "Reserved");
         }
 
-	XBIT(data, 4, "ACID");
-	XBIT(data, 1, "AI_SN");
-	XBIT(data, 1, "ACK disable");
-	XBIT(ddci, 2, "Dedicated DL Control Indicator");
+        XBIT(data, 4, "ACID");
+        XBIT(data, 1, "AI_SN");
+        XBIT(data, 1, "ACK disable");
+        XBIT(ddci, 2, "Dedicated DL Control Indicator");
 
         if ((ddci & 1) == 1) {
-	    XBIT(dur, 4, "Duration (d)");
+            XBIT(dur, 4, "Duration (d)");
             if (dur != 0) {
-		XBIT(ind, 6, "Allocation Index");
-		XBIT(per, 3, "Period (p)");
-		XBIT(ofs, 3, "Frame offset");
+                XBIT(ind, 6, "Allocation Index");
+                XBIT(per, 3, "Period (p)");
+                XBIT(ofs, 3, "Frame offset");
             }
         }
 
@@ -901,7 +901,7 @@ gint DL_HARQ_Chase_sub_burst_IE(proto_tree *diuc_tree, const guint8 *bufptr, gin
         }
     }
 
-    proto_tree_add_text(tree, tvb, BITHI(bit,4), "(DL HARQ Chase sub-burst IE)");
+    /* proto_tree_add_text(tree, tvb, BITHI(bit,4), "(DL HARQ Chase sub-burst IE)"); */
     return (BIT_TO_NIB(bit) - offset);
 }
 
@@ -930,22 +930,22 @@ gint DL_HARQ_IR_CTC_sub_burst_IE(proto_tree *diuc_tree, const guint8 *bufptr, gi
     for (j = 0; j < nsub; j++) {
         bit += RCID_IE(tree, bufptr, bit, length, tvb, RCID_Type);
 
-	XBIT(data, 4, "N(EP)");
-	XBIT(data, 4, "N(SCH)");
-	XBIT(data, 2, "SPID");
-	XBIT(data, 4, "ACID");
-	XBIT(data, 1, "AI_SN");
-	XBIT(data, 1, "ACK disable");
-	XBIT(data, 2, "Reserved");
-	XBIT(ddci, 2, "Dedicated DL Control Indicator");
+        XBIT(data, 4, "N(EP)");
+        XBIT(data, 4, "N(SCH)");
+        XBIT(data, 2, "SPID");
+        XBIT(data, 4, "ACID");
+        XBIT(data, 1, "AI_SN");
+        XBIT(data, 1, "ACK disable");
+        XBIT(data, 2, "Reserved");
+        XBIT(ddci, 2, "Dedicated DL Control Indicator");
 
         if ((ddci & 1) == 1) {
-	    XBIT(dur, 4, "Duration (d)");
+            XBIT(dur, 4, "Duration (d)");
 
             if (dur != 0) {
-		XBIT(ind, 6, "Allocation Index");
-		XBIT(per, 3, "Period (p)");
-		XBIT(ofs, 3, "Frame offset");
+                XBIT(ind, 6, "Allocation Index");
+                XBIT(per, 3, "Period (p)");
+                XBIT(ofs, 3, "Frame offset");
             }
         }
         if ((ddci & 2) == 2) {
@@ -955,16 +955,16 @@ gint DL_HARQ_IR_CTC_sub_burst_IE(proto_tree *diuc_tree, const guint8 *bufptr, gi
 
     if (include_cor2_changes)
     {
-	/* CRC-16 is always appended */
-	data = BIT_BITS(bit, bufptr, 16);
-	generic_item = proto_tree_add_text(tree, tvb, BITHI(bit,16), "CRC-16: 0x%04x",data);
-	/* calculate the CRC */
-	calculated_crc = wimax_mac_calc_crc16((guint8 *)tvb_get_ptr(tvb, 0, BIT_TO_BYTE(bit)), BIT_TO_BYTE(bit));
-	if (data != calculated_crc)
-	{
-		proto_item_append_text(generic_item, " - incorrect! (should be: 0x%x)", calculated_crc);
-	}
-	bit += 16;
+        /* CRC-16 is always appended */
+        data = BIT_BITS(bit, bufptr, 16);
+        generic_item = proto_tree_add_text(tree, tvb, BITHI(bit,16), "CRC-16: 0x%04x",data);
+        /* calculate the CRC */
+        calculated_crc = wimax_mac_calc_crc16((guint8 *)tvb_get_ptr(tvb, 0, BIT_TO_BYTE(bit)), BIT_TO_BYTE(bit));
+        if (data != calculated_crc)
+        {
+            proto_item_append_text(generic_item, " - incorrect! (should be: 0x%x)", calculated_crc);
+        }
+        bit += 16;
     }
 
     return (BIT_TO_NIB(bit) - offset);
@@ -995,30 +995,30 @@ gint DL_HARQ_IR_CC_sub_burst_IE(proto_tree *diuc_tree, const guint8 *bufptr, gin
     for (j = 0; j < nsub; j++) {
         bit += RCID_IE(tree, bufptr, bit, length, tvb, RCID_Type) / 4;
 
-	XBIT(data, 10, "Duration");
-	XBIT(sbdi,  1, "Sub-Burst DIUC Indicator");
-	XBIT(data,  1, "Reserved");
+        XBIT(data, 10, "Duration");
+        XBIT(sbdi,  1, "Sub-Burst DIUC Indicator");
+        XBIT(data,  1, "Reserved");
 
         if (sbdi) {
-	    XBIT(data, 4, "DIUC");
-	    XBIT(data, 2, "Repetition Coding Indication");
-	    XBIT(data, 2, "Reserved");
+            XBIT(data, 4, "DIUC");
+            XBIT(data, 2, "Repetition Coding Indication");
+            XBIT(data, 2, "Reserved");
         }
 
-	XBIT(data, 4, "ACID");
-	XBIT(data, 1, "AI_SN");
-	XBIT(data, 2, "SPID");
-	XBIT(data, 1, "ACK disable");
-	XBIT(ddci, 2, "Dedicated DL Control Indicator");
-	XBIT(data, 2, "Reserved");
+        XBIT(data, 4, "ACID");
+        XBIT(data, 1, "AI_SN");
+        XBIT(data, 2, "SPID");
+        XBIT(data, 1, "ACK disable");
+        XBIT(ddci, 2, "Dedicated DL Control Indicator");
+        XBIT(data, 2, "Reserved");
 
         if (ddci & 1) {
-	    XBIT(dur, 4, "Duration (d)");
+            XBIT(dur, 4, "Duration (d)");
 
             if (dur != 0) {
-		XBIT(ind, 6, "Allocation Index");
-		XBIT(per, 3, "Period (p)");
-		XBIT(ofs, 3, "Frame offset");
+                XBIT(ind, 6, "Allocation Index");
+                XBIT(per, 3, "Period (p)");
+                XBIT(ofs, 3, "Frame offset");
             }
         }
         if ((ddci & 2) == 2) {
@@ -1028,16 +1028,16 @@ gint DL_HARQ_IR_CC_sub_burst_IE(proto_tree *diuc_tree, const guint8 *bufptr, gin
 
     if (include_cor2_changes)
     {
-	/* CRC-16 is always appended */
-	data = BIT_BITS(bit, bufptr, 16);
-	generic_item = proto_tree_add_text(tree, tvb, BITHI(bit,16), "CRC-16: 0x%04x",data);
-	/* calculate the CRC */
-	calculated_crc = wimax_mac_calc_crc16((guint8 *)tvb_get_ptr(tvb, 0, BIT_TO_BYTE(bit)), BIT_TO_BYTE(bit));
-	if (data != calculated_crc)
-	{
-		proto_item_append_text(generic_item, " - incorrect! (should be: 0x%x)", calculated_crc);
-	}
-	bit += 16;
+        /* CRC-16 is always appended */
+        data = BIT_BITS(bit, bufptr, 16);
+        generic_item = proto_tree_add_text(tree, tvb, BITHI(bit,16), "CRC-16: 0x%04x",data);
+        /* calculate the CRC */
+        calculated_crc = wimax_mac_calc_crc16((guint8 *)tvb_get_ptr(tvb, 0, BIT_TO_BYTE(bit)), BIT_TO_BYTE(bit));
+        if (data != calculated_crc)
+        {
+            proto_item_append_text(generic_item, " - incorrect! (should be: 0x%x)", calculated_crc);
+        }
+        bit += 16;
     }
 
     return (BIT_TO_NIB(bit) - offset);
@@ -1066,25 +1066,25 @@ gint MIMO_DL_Chase_HARQ_sub_burst_IE(proto_tree *diuc_tree, const guint8 *bufptr
 
     nsub += 1;
     for (j = 0; j < nsub; j++) {
-	XBIT(mui, 1, "MU Indicator");
-	XBIT(dci, 1, "Dedicated MIMO DL Control Indicator");
-	XBIT(akd, 1, "ACK Disable");
+        XBIT(mui, 1, "MU Indicator");
+        XBIT(dci, 1, "Dedicated MIMO DL Control Indicator");
+        XBIT(akd, 1, "ACK Disable");
         if (mui == 0) {
             bit += RCID_IE(tree, bufptr, bit, length, tvb, RCID_Type);
         }
         if (dci == 1) {
             bit += Dedicated_MIMO_DL_Control_IE(tree, bufptr, bit, length, tvb);
         }
-	XBIT(data, 10, "Duration");
+        XBIT(data, 10, "Duration");
         for (i = 0; i < N_layer; i++) {
             if (mui == 1) {
                 bit += RCID_IE(tree, bufptr, bit, length, tvb, RCID_Type);
             }
-	    XBIT(data, 4, "DIUC");
-	    XBIT(data, 2, "Repetition Coding Indication");
+            XBIT(data, 4, "DIUC");
+            XBIT(data, 2, "Repetition Coding Indication");
             if (akd == 0) {
-		XBIT(data, 4, "ACID");
-		XBIT(data, 1, "AI_SN");
+                XBIT(data, 4, "ACID");
+                XBIT(data, 1, "AI_SN");
             }
         }
     }
@@ -1097,16 +1097,16 @@ gint MIMO_DL_Chase_HARQ_sub_burst_IE(proto_tree *diuc_tree, const guint8 *bufptr
 
     if (include_cor2_changes)
     {
-	/* CRC-16 is always appended */
-	data = BIT_BITS(bit, bufptr, 16);
-	generic_item = proto_tree_add_text(tree, tvb, BITHI(bit,16), "CRC-16: 0x%04x",data);
-	/* calculate the CRC */
-	calculated_crc = wimax_mac_calc_crc16((guint8 *)tvb_get_ptr(tvb, 0, BIT_TO_BYTE(bit)), BIT_TO_BYTE(bit));
-	if (data != calculated_crc)
-	{
-		proto_item_append_text(generic_item, " - incorrect! (should be: 0x%x)", calculated_crc);
-	}
-	bit += 16;
+        /* CRC-16 is always appended */
+        data = BIT_BITS(bit, bufptr, 16);
+        generic_item = proto_tree_add_text(tree, tvb, BITHI(bit,16), "CRC-16: 0x%04x",data);
+        /* calculate the CRC */
+        calculated_crc = wimax_mac_calc_crc16((guint8 *)tvb_get_ptr(tvb, 0, BIT_TO_BYTE(bit)), BIT_TO_BYTE(bit));
+        if (data != calculated_crc)
+        {
+            proto_item_append_text(generic_item, " - incorrect! (should be: 0x%x)", calculated_crc);
+        }
+        bit += 16;
     }
 
     return (BIT_TO_NIB(bit) - offset);
@@ -1135,41 +1135,41 @@ gint MIMO_DL_IR_HARQ_sub_burst_IE(proto_tree *diuc_tree, const guint8 *bufptr, g
 
     nsub += 1;
     for (j = 0; j < nsub; j++) {
-	XBIT(mui, 1, "MU Indicator");
-	XBIT(dci, 1, "Dedicated MIMO DL Control Indicator");
-	XBIT(akd, 1, "ACK Disable");
+        XBIT(mui, 1, "MU Indicator");
+        XBIT(dci, 1, "Dedicated MIMO DL Control Indicator");
+        XBIT(akd, 1, "ACK Disable");
         if (mui == 0) {
             bit += RCID_IE(tree, bufptr, bit, length, tvb, RCID_Type);
         }
         if (dci == 1) {
             bit += Dedicated_MIMO_DL_Control_IE(tree, bufptr, bit, length, tvb);
         }
-	XBIT(data, 4, "N(SCH)");
+        XBIT(data, 4, "N(SCH)");
         for (i = 0; i < N_layer; i++) {
             if (mui == 1) {
                 bit += RCID_IE(tree, bufptr, bit, length, tvb, RCID_Type);
             }
-	    XBIT(data, 4, "N(EP)");
+            XBIT(data, 4, "N(EP)");
             if (akd) {
-		XBIT(data, 2, "SPID");
-		XBIT(data, 4, "ACID");
-		XBIT(data, 1, "AI_SN");
+                XBIT(data, 2, "SPID");
+                XBIT(data, 4, "ACID");
+                XBIT(data, 1, "AI_SN");
             }
         }
     }
 
     if (include_cor2_changes)
     {
-	/* CRC-16 is always appended */
-	data = BIT_BITS(bit, bufptr, 16);
-	generic_item = proto_tree_add_text(tree, tvb, BITHI(bit,16), "CRC-16: 0x%04x",data);
-	/* calculate the CRC */
-	calculated_crc = wimax_mac_calc_crc16((guint8 *)tvb_get_ptr(tvb, 0, BIT_TO_BYTE(bit)), BIT_TO_BYTE(bit));
-	if (data != calculated_crc)
-	{
-		proto_item_append_text(generic_item, " - incorrect! (should be: 0x%x)", calculated_crc);
-	}
-	bit += 16;
+        /* CRC-16 is always appended */
+        data = BIT_BITS(bit, bufptr, 16);
+        generic_item = proto_tree_add_text(tree, tvb, BITHI(bit,16), "CRC-16: 0x%04x",data);
+        /* calculate the CRC */
+        calculated_crc = wimax_mac_calc_crc16((guint8 *)tvb_get_ptr(tvb, 0, BIT_TO_BYTE(bit)), BIT_TO_BYTE(bit));
+        if (data != calculated_crc)
+        {
+            proto_item_append_text(generic_item, " - incorrect! (should be: 0x%x)", calculated_crc);
+        }
+        bit += 16;
     }
 
     return (BIT_TO_NIB(bit) - offset);
@@ -1198,42 +1198,42 @@ gint MIMO_DL_IR_HARQ_for_CC_sub_burst_IE(proto_tree *diuc_tree, const guint8 *bu
 
     nsub += 1;
     for (j = 0; j < nsub; j++) {
-	XBIT(mui, 1, "MU Indicator");
-	XBIT(dci, 1, "Dedicated MIMO DL Control Indicator");
-	XBIT(akd, 1, "ACK Disable");
+        XBIT(mui, 1, "MU Indicator");
+        XBIT(dci, 1, "Dedicated MIMO DL Control Indicator");
+        XBIT(akd, 1, "ACK Disable");
         if (mui == 0) {
             bit += RCID_IE(tree, bufptr, bit, length, tvb, RCID_Type);
         }
         if (dci == 1) {
             bit += Dedicated_MIMO_DL_Control_IE(tree, bufptr, bit, length, tvb);
         }
-	XBIT(data, 10, "Duration");
+        XBIT(data, 10, "Duration");
         for (i = 0; i < N_layer; i++) {
             if (mui == 1) {
                 bit += RCID_IE(tree, bufptr, bit, length, tvb, RCID_Type);
             }
-	    XBIT(data, 4, "DIUC");
-	    XBIT(data, 2, "Repetition Coding Indication");
+            XBIT(data, 4, "DIUC");
+            XBIT(data, 2, "Repetition Coding Indication");
             if (akd == 0) {
-		XBIT(data, 4, "ACID");
-		XBIT(data, 1, "AI_SN");
-		XBIT(data, 2, "SPID");
+                XBIT(data, 4, "ACID");
+                XBIT(data, 1, "AI_SN");
+                XBIT(data, 2, "SPID");
             }
         }
     }
 
     if (include_cor2_changes)
     {
-	/* CRC-16 is always appended */
-	data = BIT_BITS(bit, bufptr, 16);
-	generic_item = proto_tree_add_text(tree, tvb, BITHI(bit,16), "CRC-16: 0x%04x",data);
-	/* calculate the CRC */
-	calculated_crc = wimax_mac_calc_crc16((guint8 *)tvb_get_ptr(tvb, 0, BIT_TO_BYTE(bit)), BIT_TO_BYTE(bit));
-	if (data != calculated_crc)
-	{
-		proto_item_append_text(generic_item, " - incorrect! (should be: 0x%x)", calculated_crc);
-	}
-	bit += 16;
+        /* CRC-16 is always appended */
+        data = BIT_BITS(bit, bufptr, 16);
+        generic_item = proto_tree_add_text(tree, tvb, BITHI(bit,16), "CRC-16: 0x%04x",data);
+        /* calculate the CRC */
+        calculated_crc = wimax_mac_calc_crc16((guint8 *)tvb_get_ptr(tvb, 0, BIT_TO_BYTE(bit)), BIT_TO_BYTE(bit));
+        if (data != calculated_crc)
+        {
+            proto_item_append_text(generic_item, " - incorrect! (should be: 0x%x)", calculated_crc);
+        }
+        bit += 16;
     }
 
     return (BIT_TO_NIB(bit) - offset);
@@ -1262,40 +1262,40 @@ gint MIMO_DL_STC_HARQ_sub_burst_IE(proto_tree *diuc_tree, const guint8 *bufptr,
 
     nsub += 1;
     for (j = 0; j < nsub; j++) {
-	XBIT(txc, 2, "TX Count");
-	XBIT(data, 10, "Duration");
-	XBIT(sbi, 1, "Sub-burst offset indication");
-	XBIT(data, 3, "Reserved");
+        XBIT(txc, 2, "TX Count");
+        XBIT(data, 10, "Duration");
+        XBIT(sbi, 1, "Sub-burst offset indication");
+        XBIT(data, 3, "Reserved");
         if (sbi == 1) {
-	    XBIT(data, 8, "Sub-burst offset");
+            XBIT(data, 8, "Sub-burst offset");
         }
         bit += RCID_IE(tree, bufptr, bit, length, tvb, RCID_Type);
-	XBIT(akd, 1, "ACK Disable");
+        XBIT(akd, 1, "ACK Disable");
         if (txc == 0) {
-	    XBIT(dmci, 1, "Dedicated MIMO DL Control Indicator");
+            XBIT(dmci, 1, "Dedicated MIMO DL Control Indicator");
             if (dmci == 1) {
                 bit += Dedicated_MIMO_DL_Control_IE(tree, bufptr, bit, length, tvb);
             }
-	    XBIT(data, 4, "DIUC");
-	    XBIT(data, 2, "Repetition coding Indication");
+            XBIT(data, 4, "DIUC");
+            XBIT(data, 2, "Repetition coding Indication");
         }
         if (akd == 0) {
-	    XBIT(data, 4, "ACID");
+            XBIT(data, 4, "ACID");
         }
     }
 
     if (include_cor2_changes)
     {
-	/* CRC-16 is always appended */
-	data = BIT_BITS(bit, bufptr, 16);
-	generic_item = proto_tree_add_text(tree, tvb, BITHI(bit,16), "CRC-16: 0x%04x",data);
-	/* calculate the CRC */
-	calculated_crc = wimax_mac_calc_crc16((guint8 *)tvb_get_ptr(tvb, 0, BIT_TO_BYTE(bit)), BIT_TO_BYTE(bit));
-	if (data != calculated_crc)
-	{
-		proto_item_append_text(generic_item, " - incorrect! (should be: 0x%x)", calculated_crc);
-	}
-	bit += 16;
+        /* CRC-16 is always appended */
+        data = BIT_BITS(bit, bufptr, 16);
+        generic_item = proto_tree_add_text(tree, tvb, BITHI(bit,16), "CRC-16: 0x%04x",data);
+        /* calculate the CRC */
+        calculated_crc = wimax_mac_calc_crc16((guint8 *)tvb_get_ptr(tvb, 0, BIT_TO_BYTE(bit)), BIT_TO_BYTE(bit));
+        if (data != calculated_crc)
+        {
+            proto_item_append_text(generic_item, " - incorrect! (should be: 0x%x)", calculated_crc);
+        }
+        bit += 16;
     }
 
     return (BIT_TO_NIB(bit) - offset);
@@ -1328,32 +1328,32 @@ gint MBS_MAP_IE(proto_tree *diuc_tree, const guint8 *bufptr, gint offset, gint l
     XBIT(mde, 1, "Macro diversity enhanced");
     if (mde == 1)
     {
-	XBIT(data, 2, "Permutation");
-	XBIT(data, 5, "DL_PermBase");
-	XBIT(data, 2, "PRBS_ID");
-	XBIT(data, 7, "OFDMA_Symbol_Offset");
-	XBIT(dci, 1, "DIUC_change_indication");
-	XBIT(data, 3, "Reserved");
+        XBIT(data, 2, "Permutation");
+        XBIT(data, 5, "DL_PermBase");
+        XBIT(data, 2, "PRBS_ID");
+        XBIT(data, 7, "OFDMA_Symbol_Offset");
+        XBIT(dci, 1, "DIUC_change_indication");
+        XBIT(data, 3, "Reserved");
         if (dci == 1) {
-	    XBIT(data, 3, "Reserved");
-	    XBIT(data, 3, "Boosting");
-	    XBIT(data, 4, "DIUC");
-	    XBIT(data, 6, "No. Subchannels");
-	    XBIT(data, 6, "No. OFDMA Symbols");
-	    XBIT(data, 2, "Repetition Coding Indication");
+            XBIT(data, 3, "Reserved");
+            XBIT(data, 3, "Boosting");
+            XBIT(data, 4, "DIUC");
+            XBIT(data, 6, "No. Subchannels");
+            XBIT(data, 6, "No. OFDMA Symbols");
+            XBIT(data, 2, "Repetition Coding Indication");
         }
     } else {
-	XBIT(data, 4, "DIUC");
-	XBIT(data, 16, "CID");
-	XBIT(data, 8, "OFDMA Symbols Offset");
-	XBIT(data, 6, "Subchannel offset");
-	XBIT(data, 3, "Boosting");
-	XBIT(s3i, 1, "SLC_3_indication");
-	XBIT(data, 6, "No. OFDMA Symbols");
-	XBIT(data, 6, "No. Subchannels");
-	XBIT(data, 2, "Repetition Coding Indication");
+        XBIT(data, 4, "DIUC");
+        XBIT(data, 16, "CID");
+        XBIT(data, 8, "OFDMA Symbols Offset");
+        XBIT(data, 6, "Subchannel offset");
+        XBIT(data, 3, "Boosting");
+        XBIT(s3i, 1, "SLC_3_indication");
+        XBIT(data, 6, "No. OFDMA Symbols");
+        XBIT(data, 6, "No. Subchannels");
+        XBIT(data, 2, "Repetition Coding Indication");
         if (s3i == 1) {
-	    XBIT(data, 8, "Next MBS_MAP_IE frame offset");
+            XBIT(data, 8, "Next MBS_MAP_IE frame offset");
         }
     }
     data = BIT_PADDING(bit, 4);
@@ -1502,7 +1502,7 @@ gint HARQ_DL_MAP_IE(proto_tree *diuc_tree, const guint8 *bufptr, gint offset, gi
     gint data;
     proto_item *ti = NULL;
     proto_tree *tree = NULL;
-    gint len, lastbit, rui, mode;
+    gint len, lastbit, rui, mode, sub_len, pad;
 
     bit = NIB_TO_BIT(offset);
 
@@ -1528,42 +1528,50 @@ gint HARQ_DL_MAP_IE(proto_tree *diuc_tree, const guint8 *bufptr, gint offset, gi
             XBIT(data,  7, "Subchannel offset");
             XBIT(data,  7, "Number of OFDMA symbols");
             XBIT(data,  7, "Number of subchannels");
-	    if (include_cor2_changes)
-	    {
-		XBIT(data,  1, "Rectangular Sub-Burst Indicator"); /* Implemented: "Rectangular Sub-Burst Indicator" field added */
-		XBIT(data,  2, "Reserved");   /* and "Reserved" field resized from 3 bits to 2 bits         */
-	    }
-	    else
-	    {
-		XBIT(data,  3, "Reserved");
-	    }
+            if (include_cor2_changes)
+            {
+                XBIT(data,  1, "Rectangular Sub-Burst Indicator"); /* Implemented: "Rectangular Sub-Burst Indicator" field added */
+                XBIT(data,  2, "Reserved");   /* and "Reserved" field resized from 3 bits to 2 bits         */
+            }
+            else
+            {
+                XBIT(data,  3, "Reserved");
+            }
         } else {
             XBIT(data,  8, "Region_ID");
         }
         XBIT(mode,  4, "Mode");
-        XBIT(data,  8, "Sub-burst IE Length");
+        XBIT(sub_len,  8, "Sub-burst IE Length");
 
         /* 8.4.5.3.21 */
         /* length of these are variable, each returns length in nibbles */
         if (mode == 0) {
-            bit += 4*DL_HARQ_Chase_sub_burst_IE(diuc_tree, bufptr, BIT_TO_NIB(bit), length, tvb);
+            DL_HARQ_Chase_sub_burst_IE(tree, bufptr, BIT_TO_NIB(bit), length, tvb);
         } else if (mode == 1) {
-            bit += 4*DL_HARQ_IR_CTC_sub_burst_IE(diuc_tree, bufptr, BIT_TO_NIB(bit), length, tvb);
+            DL_HARQ_IR_CTC_sub_burst_IE(tree, bufptr, BIT_TO_NIB(bit), length, tvb);
         } else if (mode == 2) {
-            bit += 4*DL_HARQ_IR_CC_sub_burst_IE(diuc_tree, bufptr, BIT_TO_NIB(bit), length, tvb);
+            DL_HARQ_IR_CC_sub_burst_IE(tree, bufptr, BIT_TO_NIB(bit), length, tvb);
         } else if (mode == 3) {
-            bit += 4*MIMO_DL_Chase_HARQ_sub_burst_IE(diuc_tree, bufptr, BIT_TO_NIB(bit), length, tvb);
+            MIMO_DL_Chase_HARQ_sub_burst_IE(tree, bufptr, BIT_TO_NIB(bit), length, tvb);
         } else if (mode == 4) {
-            bit += 4*MIMO_DL_IR_HARQ_sub_burst_IE(diuc_tree, bufptr, BIT_TO_NIB(bit), length, tvb);
+            MIMO_DL_IR_HARQ_sub_burst_IE(tree, bufptr, BIT_TO_NIB(bit), length, tvb);
         } else if (mode == 5) {
-            bit += 4*MIMO_DL_IR_HARQ_for_CC_sub_burst_IE(diuc_tree, bufptr, BIT_TO_NIB(bit), length, tvb);
+            MIMO_DL_IR_HARQ_for_CC_sub_burst_IE(tree, bufptr, BIT_TO_NIB(bit), length, tvb);
         } else if (mode == 6) {
-            bit += 4*MIMO_DL_STC_HARQ_sub_burst_IE(diuc_tree, bufptr, BIT_TO_NIB(bit), length, tvb);
+            MIMO_DL_STC_HARQ_sub_burst_IE(tree, bufptr, BIT_TO_NIB(bit), length, tvb);
         } else {
-            proto_tree_add_text(diuc_tree, tvb, BITHI(bit,1), "(reserved Mode)");
+            proto_tree_add_text(tree, tvb, BITHI(bit,1), "(reserved Mode)");
             break; /* cannot continue */
         }
+        bit += NIB_TO_BIT(sub_len);
     }
+
+    pad = NIB_TO_BIT(offset) + length - bit;
+    if (pad) {
+        proto_tree_add_text(tree, tvb, BITHI(bit,pad), "Padding: %d bits",pad);
+        bit += pad;
+    }
+    
     return BIT_TO_NIB(bit);
 }
 
@@ -1613,16 +1621,16 @@ gint Enhanced_DL_MAP_IE(proto_tree *diuc_tree, const guint8 *bufptr, gint offset
     XBIT(numass, 4, "Num_Assignment");
     for (i = 0; i < numass; i++) {
         if (INC_CID == 1) {
-	    XBIT(n_cid, 8, "N_CID");
+            XBIT(n_cid, 8, "N_CID");
             for (n = 0; n < n_cid; n++) {
-		XBIT(data, 16, "CID");
+                XBIT(data, 16, "CID");
             }
         }
-	XBIT(data, 4, "DIUC");
-	XBIT(data, 3, "Boosting");
-	XBIT(data, 2, "Repetition Coding Indication");
-	XBIT(data, 8, "Region_ID");
-	XBIT(data, 3, "Reserved");
+        XBIT(data, 4, "DIUC");
+        XBIT(data, 3, "Boosting");
+        XBIT(data, 2, "Repetition Coding Indication");
+        XBIT(data, 8, "Region_ID");
+        XBIT(data, 3, "Reserved");
     }
     return BIT_TO_NIB(bit);
 }
@@ -1979,14 +1987,14 @@ gint HARQ_Map_Pointer_IE(proto_tree *diuc_tree, const guint8 *bufptr, gint offse
 
     length_in_bits = NIB_TO_BIT(length-1);
     while (bit < length_in_bits) {
-	XBIT(diuc, 4, "DIUC");
-	XBIT(slots, 8, "No. Slots");
-	XBIT(rep, 2, "Repetition Coding Indication");
-	XBIT(map, 2, "Map Version");
+        XBIT(diuc, 4, "DIUC");
+        XBIT(slots, 8, "No. Slots");
+        XBIT(rep, 2, "Repetition Coding Indication");
+        XBIT(map, 2, "Map Version");
         if (map == 2) {
-	    XBIT(idle, 1, "Idle users");
-	    XBIT(sleep, 1, "Sleep users");
-	    XBIT(mask_len, 2, "CID Mask Length");
+            XBIT(idle, 1, "Idle users");
+            XBIT(sleep, 1, "Sleep users");
+            XBIT(mask_len, 2, "CID Mask Length");
             if (mask_len == 0) {
                 /* 12 bits */
                 proto_tree_add_text(diuc_tree, tvb, BITHI(bit,12), "CID Mask: 12 bits");
@@ -2030,9 +2038,9 @@ gint PHYMOD_DL_IE(proto_tree *diuc_tree, const guint8 *bufptr, gint offset, gint
 
     XBIT(pmt, 1, "Preamble Modifier Type");
     if (pmt == 0) {
-	XBIT(data, 4, "Preamble frequency shift index");
+        XBIT(data, 4, "Preamble frequency shift index");
     } else {
-	XBIT(data, 4, "Preamble Time Shift Index");
+        XBIT(data, 4, "Preamble Time Shift Index");
     }
     XBIT(data, 1, "Pilot Pattern Modifier");
     XBIT(data, 2, "Pilot Pattern Index");
@@ -2153,31 +2161,31 @@ gint UL_interference_and_noise_level_IE(proto_tree *diuc_tree, const guint8 *buf
     XNIB(data,  1, "Extended DIUC");
     XNIB(data,  1, "Length");
 
-    XNIB(bitmap,  1, "Bitmap");
+    XNIB(bitmap,  2, "Bitmap");
 
     if (bitmap & 0x01) {
-	XNIB(data, 2, "CQI/ACK/Periodic Ranging region NI");
+        XNIB(data, 2, "CQI/ACK/Periodic Ranging region NI");
     }
     if (bitmap & 0x02) {
-	XNIB(data, 2, "PUSC region NI");
+        XNIB(data, 2, "PUSC region NI");
     }
     if (bitmap & 0x04) {
-	XNIB(data, 2, "Optional PUSC region NI");
+        XNIB(data, 2, "Optional PUSC region NI");
     }
     if (bitmap & 0x08) {
-	XNIB(data, 2, "AMC region NI");
+        XNIB(data, 2, "AMC region NI");
     }
     if (bitmap & 0x10) {
-	XNIB(data, 2, "AAS region NI");
+        XNIB(data, 2, "AAS region NI");
     }
     if (bitmap & 0x20) {
-	XNIB(data, 2, "Periodic Ranging region NI");
+        XNIB(data, 2, "Periodic Ranging region NI");
     }
     if (bitmap & 0x40) {
-	XNIB(data, 2, "Sounding region NI");
+        XNIB(data, 2, "Sounding region NI");
     }
     if (bitmap & 0x80) {
-	XNIB(data, 2, "MIMO region NI");
+        XNIB(data, 2, "MIMO region NI");
     }
 
     return nib;
@@ -2194,14 +2202,14 @@ void proto_register_mac_mgmt_msg_dlmap(void)
 {
     if (proto_mac_mgmt_msg_dlmap_decoder == -1)
     {
-	proto_mac_mgmt_msg_dlmap_decoder = proto_register_protocol (
-						"WiMax DLMAP/ULMAP Messages", /* name */
-						"WiMax DLMAP/ULMAP (map)", /* short name */
-						"wmx.map" /* abbrev */
-						);
+        proto_mac_mgmt_msg_dlmap_decoder = proto_register_protocol (
+                "WiMax DLMAP/ULMAP Messages", /* name */
+                "WiMax DLMAP/ULMAP (map)", /* short name */
+                "wmx.map" /* abbrev */
+                );
 
-	proto_register_field_array(proto_mac_mgmt_msg_dlmap_decoder, hf, array_length(hf));
-	proto_register_subtree_array(ett, array_length(ett));
+        proto_register_field_array(proto_mac_mgmt_msg_dlmap_decoder, hf, array_length(hf));
+        proto_register_subtree_array(ett, array_length(ett));
     }
 }
 
@@ -2276,7 +2284,7 @@ gint dissect_dlmap_ie(proto_tree *ie_tree, const guint8 *bufptr, gint offset, gi
                 break;
             case 0x07:
                 /* 8.4.5.3.21 HARQ_DL_MAP_IE */
-                nibble += HARQ_DL_MAP_IE(tree, bufptr, nibble, len, tvb);
+                nibble = HARQ_DL_MAP_IE(tree, bufptr, nibble, len, tvb);
                 break;
             case 0x08:
                 /* 8.4.5.3.22 HARQ_ACK IE */
@@ -2290,12 +2298,12 @@ gint dissect_dlmap_ie(proto_tree *ie_tree, const guint8 *bufptr, gint offset, gi
                 /* 8.4.5.3.24 Closed-loop MIMO DL Enhanced IE */
                 nibble = Closed_loop_MIMO_DL_Enhanced_IE(tree, bufptr, nibble, len, tvb);
                 break;
-	    case 0x0b:
-		nibble = MIMO_DL_Basic_IE(tree, bufptr, nibble, len, tvb);
-		break;
-	    case 0x0c:
-		nibble = MIMO_DL_Enhanced_IE(tree, bufptr, nibble, len, tvb);
-		break;
+            case 0x0b:
+                nibble = MIMO_DL_Basic_IE(tree, bufptr, nibble, len, tvb);
+                break;
+            case 0x0c:
+                nibble = MIMO_DL_Enhanced_IE(tree, bufptr, nibble, len, tvb);
+                break;
 
             case 0x0e:
                 nibble = AAS_SDMA_DL_IE(tree, bufptr, nibble, len, tvb);
@@ -2303,7 +2311,7 @@ gint dissect_dlmap_ie(proto_tree *ie_tree, const guint8 *bufptr, gint offset, gi
 
             default:
                 proto_tree_add_text(tree, tvb, NIBHI(nibble,len), "(reserved Extended-2 DIUC: %d)", ext2_diuc);
-		nibble += len;
+                nibble += len;
                 break;
 
         }
@@ -2359,9 +2367,9 @@ gint dissect_dlmap_ie(proto_tree *ie_tree, const guint8 *bufptr, gint offset, gi
                 /* 8.4.5.3.13 DL PUSC Burst Allocation in Other Segment IE */
                 nibble = DL_PUSC_Burst_Allocation_in_Other_Segment_IE(tree, bufptr, nibble, len, tvb);
                 break;
-	    case 0x0c:
-		nibble = PUSC_ASCA_Alloc_IE(tree, bufptr, nibble, len, tvb);
-		break;
+            case 0x0c:
+                nibble = PUSC_ASCA_Alloc_IE(tree, bufptr, nibble, len, tvb);
+                break;
 
             case 0x0f:
                 /* 8.4.5.3.19 UL_interference_and_noise_level_IE */
@@ -2370,7 +2378,7 @@ gint dissect_dlmap_ie(proto_tree *ie_tree, const guint8 *bufptr, gint offset, gi
 
             default:
                 proto_tree_add_text(tree, tvb, NIBHI(nibble,len), "(reserved Extended DIUC: %d)", ext_diuc);
-		nibble += len;
+                nibble += len;
                 break;
         }
     }
@@ -2404,7 +2412,7 @@ gint dissect_dlmap_ie(proto_tree *ie_tree, const guint8 *bufptr, gint offset, gi
         if (INC_CID)
         {
             n_cid = NIB_BYTE(nibble, bufptr);
-            proto_tree_add_item(tree, hf_dlmap_ie_ncid, tvb, NIBHI(nibble,2), FALSE);
+            proto_tree_add_uint(tree, hf_dlmap_ie_ncid, tvb, NIBHI(nibble, 2), n_cid);
             nibble += 2;
 
             for (i = 0; i < n_cid; i++)
@@ -2414,7 +2422,8 @@ gint dissect_dlmap_ie(proto_tree *ie_tree, const guint8 *bufptr, gint offset, gi
                     /* RCID_Type comes from 6.3.2.3.43.2 [2] Format_configuration_IE in Compact_DL-MAP_IE */
                     nibble += RCID_IE(tree, bufptr, nibble*4, length, tvb, RCID_Type) / 4;
                 } else {
-                    proto_tree_add_item(tree, hf_dlmap_ie_cid, tvb, NIBHI(nibble,4), FALSE);
+                    data = NIB_WORD(nibble, bufptr);
+                    proto_tree_add_uint(tree, hf_dlmap_ie_cid, tvb, NIBHI(nibble, 4), data);
                     nibble += 4;
                 }
             }
@@ -2524,7 +2533,7 @@ gint wimax_decode_dlmapc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *base_tre
     /* update the info column */
     if (check_col(pinfo->cinfo, COL_INFO))
     {
-	col_append_sep_str(pinfo->cinfo, COL_INFO, NULL, "Compressed DL-MAP");
+        col_append_sep_str(pinfo->cinfo, COL_INFO, NULL, "Compressed DL-MAP");
     }
 
     INC_CID = 0;
@@ -2557,19 +2566,19 @@ gint wimax_decode_dlmapc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *base_tre
     /* DL-MAP IEs */
     length -= 15; /* remaining length in bytes (11 bytes above + CRC at end) */
     if (dl_ie_count) {
-	ti = proto_tree_add_text(tree, tvb, offset, length, "DL-MAP IEs (%d bytes)", length);
-	ie_tree = proto_item_add_subtree(ti, ett_dlmap_ie);
+        ti = proto_tree_add_text(tree, tvb, offset, length, "DL-MAP IEs (%d bytes)", length);
+        ie_tree = proto_item_add_subtree(ti, ett_dlmap_ie);
 
-	length = BYTE_TO_NIB(mac_len - sizeof(mac_crc) - 1); /* convert length to nibbles */
+        length = BYTE_TO_NIB(mac_len - sizeof(mac_crc) - 1); /* convert length to nibbles */
 
-	while (nib < length) {
-	    nib += dissect_dlmap_ie(ie_tree, bufptr, nib, tvb_len * 2, tvb);
-	}
-	pad = NIB_PADDING(nib);
-	if (pad) {
-	    proto_tree_add_text(tree, tvb, NIBHI(nib,1), "Padding nibble");
-	    nib++;
-	}
+        while (dl_ie_count--) {
+            nib += dissect_dlmap_ie(ie_tree, bufptr, nib, tvb_len * 2, tvb);
+        }
+        pad = NIB_PADDING(nib);
+        if (pad) {
+            proto_tree_add_text(tree, tvb, NIBHI(nib,1), "Padding nibble");
+            nib++;
+        }
     }
 
     if (ulmap_appended) {
@@ -2580,20 +2589,20 @@ gint wimax_decode_dlmapc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *base_tre
     /* CRC is always appended */
     /* check the length */
     if (MIN(tvb_len, tvb_reported_length(tvb)) >= mac_len)
-    {	/* get the CRC */
-	    mac_crc = tvb_get_ntohl(tvb, mac_len - sizeof(mac_crc));
-	    /* calculate the CRC */
-	    calculated_crc = wimax_mac_calc_crc32((guint8 *)tvb_get_ptr(tvb, 0, mac_len - sizeof(mac_crc)), mac_len - sizeof(mac_crc));
-	    /* display the CRC */
-	    generic_item = proto_tree_add_item(base_tree, hf_mac_header_compress_dlmap_crc, tvb, mac_len - sizeof(mac_crc), sizeof(mac_crc), FALSE);
-	    if (mac_crc != calculated_crc)
-	    {
-		    proto_item_append_text(generic_item, " - incorrect! (should be: 0x%x)", calculated_crc);
-	    }
+    {   /* get the CRC */
+        mac_crc = tvb_get_ntohl(tvb, mac_len - sizeof(mac_crc));
+        /* calculate the CRC */
+        calculated_crc = wimax_mac_calc_crc32((guint8 *)tvb_get_ptr(tvb, 0, mac_len - sizeof(mac_crc)), mac_len - sizeof(mac_crc));
+        /* display the CRC */
+        generic_item = proto_tree_add_item(base_tree, hf_mac_header_compress_dlmap_crc, tvb, mac_len - sizeof(mac_crc), sizeof(mac_crc), FALSE);
+        if (mac_crc != calculated_crc)
+        {
+            proto_item_append_text(generic_item, " - incorrect! (should be: 0x%x)", calculated_crc);
+        }
     }
     else
-    {	/* display error message */
-	    proto_tree_add_protocol_format(base_tree, proto_mac_mgmt_msg_dlmap_decoder, tvb, 0, tvb_len, "CRC missing - the frame is too short (%u bytes)", tvb_len);
+    {   /* display error message */
+        proto_tree_add_protocol_format(base_tree, proto_mac_mgmt_msg_dlmap_decoder, tvb, 0, tvb_len, "CRC missing - the frame is too short (%u bytes)", tvb_len);
     }
 
     return mac_len;
@@ -2686,7 +2695,7 @@ gint wimax_decode_sub_dl_ul_map(tvbuff_t *tvb, packet_info *pinfo, proto_tree *b
     calculated_crc = wimax_mac_calc_crc16((guint8 *)tvb_get_ptr(tvb, 0, NIB_TO_BYTE(nib)), NIB_TO_BYTE(nib));
     if (data != calculated_crc)
     {
-	    proto_item_append_text(generic_item, " - incorrect! (should be: 0x%x)", calculated_crc);
+        proto_item_append_text(generic_item, " - incorrect! (should be: 0x%x)", calculated_crc);
     }
     nib += 4;
 
@@ -2815,7 +2824,7 @@ gint wimax_decode_dlmap_reduced_aas(tvbuff_t *tvb, packet_info *pinfo, proto_tre
     calculated_crc = wimax_mac_calc_crc16((guint8 *)tvb_get_ptr(tvb, 0, BIT_TO_BYTE(bit)), BIT_TO_BYTE(bit));
     if (data != calculated_crc)
     {
-	    proto_item_append_text(generic_item, " - incorrect! (should be: 0x%x)", calculated_crc);
+        proto_item_append_text(generic_item, " - incorrect! (should be: 0x%x)", calculated_crc);
     }
     bit += 16;
 
