@@ -1,6 +1,6 @@
 /* netxray.c
  *
- * $Id: netxray.c 27164 2009-01-06 13:31:28Z wmeier $
+ * $Id: netxray.c 28144 2009-04-24 12:16:01Z wmeier $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -194,7 +194,7 @@ struct netxray_hdr {
  *  CAPTYPE_ATM?  If so, what should the table for ATM captures with
  *  that captype be?
  */
-static double TpS[] = { 1e6, 1193000.0, 1193182.0 };
+static const double TpS[] = { 1e6, 1193000.0, 1193182.0 };
 #define NUM_NETXRAY_TIMEUNITS (sizeof TpS / sizeof TpS[0])
 
 /*
@@ -219,7 +219,7 @@ static double TpS[] = { 1e6, 1193000.0, 1193182.0 };
  * (Based upon captures reviewed realtick does not contain the 
  *   correct TpS values for the 'gigpod' captype).
  */
-static double TpS_gigpod[] = { 1e9, 0.0, 31250000.0 };
+static const double TpS_gigpod[] = { 1e9, 0.0, 31250000.0 };
 #define NUM_NETXRAY_TIMEUNITS_GIGPOD (sizeof TpS_gigpod / sizeof TpS_gigpod[0])
 
 /*
@@ -227,7 +227,7 @@ static double TpS_gigpod[] = { 1e9, 0.0, 31250000.0 };
  *  (Based upon captures reviewed realtick does not contain the 
  *   correct TpS values for the 'otherpod' captype).
  */
-static double TpS_otherpod[] = { 1e6, 0.0, 1250000.0 }; 
+static const double TpS_otherpod[] = { 1e6, 0.0, 1250000.0 }; 
 #define NUM_NETXRAY_TIMEUNITS_OTHERPOD (sizeof TpS_otherpod / sizeof TpS_otherpod[0])
 
 /*
@@ -235,7 +235,7 @@ static double TpS_otherpod[] = { 1e6, 0.0, 1250000.0 };
  * (Based upon captures reviewed realtick does not contain the 
  *   correct TpS values for the 'otherpod2' captype).
  */
-static double TpS_otherpod2[] = { 1e6, 0.0, 0.0 }; 
+static const double TpS_otherpod2[] = { 1e6, 0.0, 0.0 }; 
 #define NUM_NETXRAY_TIMEUNITS_OTHERPOD2 (sizeof TpS_otherpod2 / sizeof TpS_otherpod2[0])
 
 /*
@@ -243,7 +243,7 @@ static double TpS_otherpod2[] = { 1e6, 0.0, 0.0 };
  * (Based upon captures reviewed realtick does not contain the 
  *   correct TpS values for the 'gigpod2' captype).
  */
-static double TpS_gigpod2[] = { 1e9, 0.0, 20000000.0 };
+static const double TpS_gigpod2[] = { 1e9, 0.0, 20000000.0 };
 #define NUM_NETXRAY_TIMEUNITS_GIGPOD2 (sizeof TpS_gigpod2 / sizeof TpS_gigpod2[0])
 
 /* Version number strings. */
@@ -996,7 +996,7 @@ reread:
 		t /= wth->capture.netxray->ticks_per_sec;
 		t -= wth->capture.netxray->start_timestamp;
 		wth->phdr.ts.secs = wth->capture.netxray->start_time + (long)t;
-		wth->phdr.ts.nsecs = (unsigned long)((t-(double)(unsigned long)(t))
+		wth->phdr.ts.nsecs = (int)((t-(double)(unsigned long)(t))
 			*1.0e9);
 		/*
 		 * We subtract the padding from the packet size, so our caller
@@ -1009,8 +1009,8 @@ reread:
 		    + (double)pletohl(&hdr.hdr_1_x.timehi)*4294967296.0;
 		t /= wth->capture.netxray->ticks_per_sec;
 		t -= wth->capture.netxray->start_timestamp;
-		wth->phdr.ts.secs = wth->capture.netxray->start_time + (long)t;
-		wth->phdr.ts.nsecs = (unsigned long)((t-(double)(unsigned long)(t))
+		wth->phdr.ts.secs = wth->capture.netxray->start_time + (time_t)t;
+		wth->phdr.ts.nsecs = (int)((t-(double)(unsigned long)(t))
 			*1.0e9);
 		/*
 		 * We subtract the padding from the packet size, so our caller
@@ -1592,7 +1592,7 @@ static gboolean netxray_dump_close_1_1(wtap_dumper *wdh, int *err)
     struct netxray_hdr file_hdr;
     size_t nwritten;
 
-    filelen = ftell(wdh->fh);
+    filelen = (guint32)ftell(wdh->fh);	/* XXX - large files? */
 
     /* Go back to beginning */
     fseek(wdh->fh, 0, SEEK_SET);
@@ -1802,7 +1802,7 @@ static gboolean netxray_dump_close_2_0(wtap_dumper *wdh, int *err)
     struct netxray_hdr file_hdr;
     size_t nwritten;
 
-    filelen = ftell(wdh->fh);
+    filelen = (guint32)ftell(wdh->fh);	/* XXX - large files? */
 
     /* Go back to beginning */
     fseek(wdh->fh, 0, SEEK_SET);
